@@ -5,6 +5,14 @@ use base qw(Business::ISBN);
 use Business::ISBN qw(:all);
 use Data::Dumper;
 
+use subs qw(
+	_checksum
+	INVALID_COUNTRY_CODE
+	INVALID_PUBLISHER_CODE
+	BAD_CHECKSUM
+	GOOD_ISBN
+	BAD_ISBN
+	);
 use vars qw(
 	$VERSION
 	$debug
@@ -14,7 +22,7 @@ use Carp qw(carp croak cluck);
 
 my $debug = 0;
 
-$VERSION   = '2.011';
+$VERSION   = '2.08';
 
 sub _max_length { 13 }
 
@@ -92,8 +100,6 @@ sub _checksum {
 
 __END__
 
-=encoding utf8
-
 =head1 NAME
 
 Business::ISBN13 - work with 13 digit International Standard Book Numbers
@@ -110,7 +116,7 @@ See L<Business::ISBN>
 
 This source is in Github.
 
-	https://github.com/briandfoy/business-isbn
+	https://github.com/briandfoy/business--isbn
 
 =head1 AUTHOR
 
@@ -118,7 +124,7 @@ brian d foy C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2001-2015, brian d foy <bdfoy@cpan.org>. All rights reserved.
+Copyright (c) 2001-2014, brian d foy, All Rights Reserved.
 
 You may redistribute this under the same terms as Perl itself.
 
